@@ -3,6 +3,7 @@
 #include <stdexcept>
 #include <vector>
 #include <algorithm>
+#include <limits>
 
 #include <QUdpSocket>
 #include <QHostInfo>
@@ -11,6 +12,7 @@
 #include <QByteArray>
 #include <QHostAddress>
 #include <QColor>
+#include <QDebug>
 
 #include "NetworkMessage.hpp"
 
@@ -18,6 +20,13 @@
 
 #include "moc_MessageClient.cpp"
 
+// some trace macros
+#if WSJT_TRACE_UDP
+#define TRACE_UDP(MSG) qDebug () << QString {"MessageClient::%1:"}.arg (__func__) << MSG
+#else
+#define TRACE_UDP(MSG)
+#endif
+
 class MessageClient::impl
   : public QUdpSocket
 {
@@ -27,6 +36,7 @@ public:
   impl (QString const& id, QString const& version, QString const& revision,
         port_type server_port, MessageClient * self)
     : self_ {self}
+    , enabled_ {false}
     , id_ {id}
     , version_ {version}
     , revision_ {revision}
@@ -71,6 +81,7 @@ public:
   Q_SLOT void host_info_results (QHostInfo);
 
   MessageClient * self_;
+  bool enabled_;
   QString id_;
   QString version_;
   QString revision_;
@@ -101,6 +112,7 @@ void MessageClient::impl::host_info_results (QHostInfo host_info)
       if (blocked_addresses_.end () == std::find (blocked_addresses_.begin (), blocked_addresses_.end (), server))
         {
           server_ = server;
+          TRACE_UDP ("resulting server:" << server);
 
           // send initial heartbeat which allows schema negotiation
           heartbeat ();
@@ -129,6 +141,7 @@ void MessageClient::impl::pending_datagrams ()
       port_type sender_port;
       if (0 <= readDatagram (datagram.data (), datagram.size (), &sender_address, &sender_port))
         {
+          TRACE_UDP ("message received from:" << sender_address << "port:" << sender_port);
           parse_message (datagram);
         }
     }
@@ -142,7 +155,7 @@ void MessageClient::impl::parse_message (QByteArray const& msg)
       // message format is described in NetworkMessage.hpp
       // 
       NetworkMessage::Reader in {msg};
-      if (OK == check_status (in) && id_ == in.id ()) // OK and for us
+      if (OK == check_status (in))
         {
           if (schema_ < in.schema ()) // one time record of server's
                                       // negotiated schema
@@ -150,6 +163,12 @@ void MessageClient::impl::parse_message (QByteArray const& msg)
               schema_ = in.schema ();
             }
 
+          if (!enabled_)
+            {
+              TRACE_UDP ("message processing disabled for id:" << in.id ());
+              return;
+            }
+
           //
           // message format is described in NetworkMessage.hpp
           //
@@ -168,6 +187,7 @@ void MessageClient::impl::parse_message (QByteArray const& msg)
                 quint8 modifiers {0};
                 in >> time >> snr >> delta_time >> delta_frequency >> mode >> message
                    >> low_confidence >> modifiers;
+                TRACE_UDP ("Reply: time:" << time << "snr:" << snr << "dt:" << delta_time << "df:" << delta_frequency << "mode:" << mode << "message:" << message << "low confidence:" << low_confidence << "modifiers: 0x" << hex << modifiers);
                 if (check_status (in) != Fail)
                   {
                     Q_EMIT self_->reply (time, snr, delta_time, delta_frequency
@@ -177,7 +197,29 @@ void MessageClient::impl::parse_message (QByteArray const& msg)
               }
               break;
 
+            case NetworkMessage::Clear:
+              {
+                quint8 window {0};
+                in >> window;
+                TRACE_UDP ("Clear window:" << window);
+                if (check_status (in) != Fail)
+                  {
+                    Q_EMIT self_->clear_decodes (window);
+                  }
+              }
+              break;
+
+            case NetworkMessage::Close:
+              TRACE_UDP ("Close");
+              if (check_status (in) != Fail)
+                {
+                  last_message_.clear ();
+                  Q_EMIT self_->close ();
+                }
+              break;
+
             case NetworkMessage::Replay:
+              TRACE_UDP ("Replay");
               if (check_status (in) != Fail)
                 {
                   last_message_.clear ();
@@ -189,6 +231,7 @@ void MessageClient::impl::parse_message (QByteArray const& msg)
               {
                 bool auto_only {false};
                 in >> auto_only;
+                TRACE_UDP ("Halt Tx auto_only:" << auto_only);
                 if (check_status (in) != Fail)
                   {
                     Q_EMIT self_->halt_tx (auto_only);
@@ -201,6 +244,7 @@ void MessageClient::impl::parse_message (QByteArray const& msg)
                 QByteArray message;
                 bool send {true};
                 in >> message >> send;
+                TRACE_UDP ("FreeText message:" << message << "send:" << send);
                 if (check_status (in) != Fail)
                   {
                     Q_EMIT self_->free_text (QString::fromUtf8 (message), send);
@@ -212,6 +256,7 @@ void MessageClient::impl::parse_message (QByteArray const& msg)
               {
                 QByteArray location;
                 in >> location;
+                TRACE_UDP ("Location location:" << location);
                 if (check_status (in) != Fail)
                 {
                     Q_EMIT self_->location (QString::fromUtf8 (location));
@@ -226,6 +271,7 @@ void MessageClient::impl::parse_message (QByteArray const& msg)
                 QColor fg;      // default invalid color
                 bool last_only {false};
                 in >> call >> bg >> fg >> last_only;
+                TRACE_UDP ("HighlightCallsign call:" << call << "bg:" << bg << "fg:" << fg << "last only:" << last_only);
                 if (check_status (in) != Fail && call.size ())
                   {
                     Q_EMIT self_->highlight_callsign (QString::fromUtf8 (call), bg, fg, last_only);
@@ -233,6 +279,42 @@ void MessageClient::impl::parse_message (QByteArray const& msg)
               }
               break;
 
+            case NetworkMessage::SwitchConfiguration:
+              {
+                QByteArray configuration_name;
+                in >> configuration_name;
+                TRACE_UDP ("Switch Configuration name:" << configuration_name);
+                if (check_status (in) != Fail)
+                  {
+                    Q_EMIT self_->switch_configuration (QString::fromUtf8 (configuration_name));
+                  }
+              }
+              break;
+
+            case NetworkMessage::Configure:
+              {
+                QByteArray mode;
+                quint32 frequency_tolerance;
+                QByteArray submode;
+                bool fast_mode {false};
+                quint32 tr_period {std::numeric_limits<quint32>::max ()};
+                quint32 rx_df {std::numeric_limits<quint32>::max ()};
+                QByteArray dx_call;
+                QByteArray dx_grid;
+                bool generate_messages {false};
+                in >> mode >> frequency_tolerance >> submode >> fast_mode >> tr_period >> rx_df
+                   >> dx_call >> dx_grid >> generate_messages;
+                TRACE_UDP ("Configure mode:" << mode << "frequency tolerance:" << frequency_tolerance << "submode:" << submode << "fast mode:" << fast_mode << "T/R period:" << tr_period << "rx df:" << rx_df << "dx call:" << dx_call << "dx grid:" << dx_grid << "generate messages:" << generate_messages);
+                if (check_status (in) != Fail)
+                  {
+                    Q_EMIT self_->configure (QString::fromUtf8 (mode), frequency_tolerance
+                                             , QString::fromUtf8 (submode), fast_mode, tr_period, rx_df
+                                             , QString::fromUtf8 (dx_call), QString::fromUtf8 (dx_grid)
+                                             , generate_messages);
+                  }
+              }
+              break;
+
             default:
               // Ignore
               //
@@ -240,9 +322,17 @@ void MessageClient::impl::parse_message (QByteArray const& msg)
               // parsed here  they are  still partially parsed  in the
               // message reader class to  negotiate the maximum schema
               // number being used on the network.
+              if (NetworkMessage::Heartbeat != in.type ())
+                {
+                  TRACE_UDP ("ignoring message type:" << in.type ());
+                }
               break;
             }
         }
+      else
+        {
+          TRACE_UDP ("ignored message for id:" << in.id ());
+        }
     }
   catch (std::exception const& e)
     {
@@ -264,6 +354,7 @@ void MessageClient::impl::heartbeat ()
          << version_.toUtf8 () << revision_.toUtf8 ();
       if (OK == check_status (hb))
         {
+          TRACE_UDP ("schema:" << schema_ << "max schema:" << NetworkMessage::Builder::schema_number << "version:" << version_ << "revision:" << revision_);
           writeDatagram (message, server_, server_port_);
         }
     }
@@ -277,6 +368,7 @@ void MessageClient::impl::closedown ()
       NetworkMessage::Builder out {&message, NetworkMessage::Close, id_, schema_};
       if (OK == check_status (out))
         {
+          TRACE_UDP ("");
           writeDatagram (message, server_, server_port_);
         }
     }
@@ -369,6 +461,7 @@ void MessageClient::set_server (QString const& server)
   if (!server.isEmpty ())
     {
       // queue a host address lookup
+      TRACE_UDP ("server host DNS lookup:" << server);
       QHostInfo::lookupHost (server, &*m_, SLOT (host_info_results (QHostInfo)));
     }
 }
@@ -399,13 +492,20 @@ void MessageClient::add_blocked_destination (QHostAddress const& a)
     }
 }
 
+void MessageClient::enable (bool flag)
+{
+  m_->enabled_ = flag;
+}
+
 void MessageClient::status_update (Frequency f, QString const& mode, QString const& dx_call
                                    , QString const& report, QString const& tx_mode
                                    , bool tx_enabled, bool transmitting, bool decoding
-                                   , qint32 rx_df, qint32 tx_df, QString const& de_call
+                                   , quint32 rx_df, quint32 tx_df, QString const& de_call
                                    , QString const& de_grid, QString const& dx_grid
                                    , bool watchdog_timeout, QString const& sub_mode
-                                   , bool fast_mode, quint8 special_op_mode)
+                                   , bool fast_mode, quint8 special_op_mode
+                                   , quint32 frequency_tolerance, quint32 tr_period
+                                   , QString const& configuration_name)
 {
   if (m_->server_port_ && !m_->server_string_.isEmpty ())
     {
@@ -414,7 +514,8 @@ void MessageClient::status_update (Frequency f, QString const& mode, QString con
       out << f << mode.toUtf8 () << dx_call.toUtf8 () << report.toUtf8 () << tx_mode.toUtf8 ()
           << tx_enabled << transmitting << decoding << rx_df << tx_df << de_call.toUtf8 ()
           << de_grid.toUtf8 () << dx_grid.toUtf8 () << watchdog_timeout << sub_mode.toUtf8 ()
-          << fast_mode << special_op_mode;
+          << fast_mode << special_op_mode << frequency_tolerance << tr_period << configuration_name.toUtf8 ();
+      TRACE_UDP ("frequency:" << f << "mode:" << mode << "DX:" << dx_call << "report:" << report << "Tx mode:" << tx_mode << "tx_enabled:" << tx_enabled << "Tx:" << transmitting << "decoding:" << decoding << "Rx df:" << rx_df << "Tx df:" << tx_df << "DE:" << de_call << "DE grid:" << de_grid << "DX grid:" << dx_grid << "w/d t/o:" << watchdog_timeout << "sub_mode:" << sub_mode << "fast mode:" << fast_mode << "spec op mode:" << special_op_mode << "frequency tolerance:" << frequency_tolerance << "T/R period:" << tr_period << "configuration name:" << configuration_name);
       m_->send_message (out, message);
     }
 }
@@ -429,6 +530,7 @@ void MessageClient::decode (bool is_new, QTime time, qint32 snr, float delta_tim
       NetworkMessage::Builder out {&message, NetworkMessage::Decode, m_->id_, m_->schema_};
       out << is_new << time << snr << delta_time << delta_frequency << mode.toUtf8 ()
           << message_text.toUtf8 () << low_confidence << off_air;
+      TRACE_UDP ("new" << is_new << "time:" << time << "snr:" << snr << "dt:" << delta_time << "df:" << delta_frequency << "mode:" << mode << "text:" << message_text << "low conf:" << low_confidence << "off air:" << off_air);
       m_->send_message (out, message);
     }
 }
@@ -443,16 +545,18 @@ void MessageClient::WSPR_decode (bool is_new, QTime time, qint32 snr, float delt
       NetworkMessage::Builder out {&message, NetworkMessage::WSPRDecode, m_->id_, m_->schema_};
       out << is_new << time << snr << delta_time << frequency << drift << callsign.toUtf8 ()
           << grid.toUtf8 () << power << off_air;
+      TRACE_UDP ("new:" << is_new << "time:" << time << "snr:" << snr << "dt:" << delta_time << "frequency:" << frequency << "drift:" << drift << "call:" << callsign << "grid:" << grid << "pwr:" << power << "off air:" << off_air);
       m_->send_message (out, message);
     }
 }
 
-void MessageClient::clear_decodes ()
+void MessageClient::decodes_cleared ()
 {
    if (m_->server_port_ && !m_->server_string_.isEmpty ())
     {
       QByteArray message;
       NetworkMessage::Builder out {&message, NetworkMessage::Clear, m_->id_, m_->schema_};
+      TRACE_UDP ("");
       m_->send_message (out, message);
     }
 }
@@ -473,6 +577,7 @@ void MessageClient::qso_logged (QDateTime time_off, QString const& dx_call, QStr
           << report_sent.toUtf8 () << report_received.toUtf8 () << tx_power.toUtf8 () << comments.toUtf8 ()
           << name.toUtf8 () << time_on << operator_call.toUtf8 () << my_call.toUtf8 () << my_grid.toUtf8 ()
           << exchange_sent.toUtf8 () << exchange_rcvd.toUtf8 ();
+      TRACE_UDP ("time off:" << time_off << "DX:" << dx_call << "DX grid:" << dx_grid << "dial:" << dial_frequency << "mode:" << mode << "sent:" << report_sent << "rcvd:" << report_received << "pwr:" << tx_power << "comments:" << comments << "name:" << name << "time on:" << time_on << "op:" << operator_call << "DE:" << my_call << "DE grid:" << my_grid << "exch sent:" << exchange_sent << "exch rcvd:" << exchange_rcvd);
       m_->send_message (out, message);
     }
 }
@@ -483,8 +588,9 @@ void MessageClient::logged_ADIF (QByteArray const& ADIF_record)
     {
       QByteArray message;
       NetworkMessage::Builder out {&message, NetworkMessage::LoggedADIF, m_->id_, m_->schema_};
-      QByteArray ADIF {"\n<adif_ver:5>3.0.7\n<programid:6>WSJT-X\n<EOH>\n" + ADIF_record + " <EOR>"};
+      QByteArray ADIF {"\n<adif_ver:5>3.1.0\n<programid:6>WSJT-X\n<EOH>\n" + ADIF_record + " <EOR>"};
       out << ADIF;
+      TRACE_UDP ("ADIF:" << ADIF);
       m_->send_message (out, message);
     }
 }
