@@ -34,7 +34,7 @@ program encode77
      i3=-1
      n3=-1
      call pack77(msg0(1:37),i3,n3,c77)
-     call unpack77(c77,msg,unpk77_success)
+     call unpack77(c77,1,msg,unpk77_success)
      cerr=' '
      if(msg.ne.msg0(1:37)) cerr='*'
      if(i3.eq.0) write(*,1004) i3,n3,cerr,msg0(1:37),msg
