@@ -17,7 +17,7 @@ subroutine genft8(msg,i3,n3,msgsent,msgbits,itone)
   i3=-1
   n3=-1
   call pack77(msg,i3,n3,c77)
-  call unpack77(c77,msgsent,unpk77_success)
+  call unpack77(c77,0,msgsent,unpk77_success)
   read(c77,'(77i1)',err=1) msgbits
   if(unpk77_success) go to 2
 1 msgbits=0
@@ -25,7 +25,7 @@ subroutine genft8(msg,i3,n3,msgsent,msgbits,itone)
   msgsent='*** bad message ***                  '
   go to 900
 
-entry get_tones_from_77bits(msgbits,itone) 
+entry get_ft8_tones_from_77bits(msgbits,itone) 
 
 2  call encode174_91(msgbits,codeword)      !Encode the test message
 
