@@ -5,6 +5,7 @@
 #include "AD1CCty.hpp"
 #include "pimpl_h.hpp"
 
+class Configuration;
 class CountryDat;
 class QString;
 class QByteArray;
@@ -17,7 +18,7 @@ class WorkedBefore final
 public:
   using Continent = AD1CCty::Continent;
 
-  explicit WorkedBefore ();
+  explicit WorkedBefore (Configuration const *);
   ~WorkedBefore ();
 
   Q_SLOT void reload ();
@@ -28,7 +29,7 @@ public:
                    , QByteArray const& ADIF_record);
 
   QString const& path () const;
-  AD1CCty const& countries () const;
+  AD1CCty const * countries () const;
   bool country_worked (QString const& call, QString const& mode, QString const& band) const;
   bool grid_worked (QString const& grid, QString const& mode, QString const& band) const;
   bool call_worked (QString const& call, QString const& mode, QString const& band) const;
